Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(102)

Unified Diff: tests/compiler/dart2js/analyze_unused_dart2js_test.dart

Issue 1342213003: Add optional message to assert in Dart2js - continued (Closed) Base URL: https://github.com/dart-lang/sdk.git@master
Patch Set: Add --assert-message flag Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/core/errors.dart ('k') | tests/compiler/dart2js/backend_dart/dart_printer_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/compiler/dart2js/analyze_unused_dart2js_test.dart
diff --git a/tests/compiler/dart2js/analyze_unused_dart2js_test.dart b/tests/compiler/dart2js/analyze_unused_dart2js_test.dart
index 8c68b18d92064f24d938922819326cf5aa670adc..10fc5a594476a96a9f3536a2cc6b00fa81a65cf4 100644
--- a/tests/compiler/dart2js/analyze_unused_dart2js_test.dart
+++ b/tests/compiler/dart2js/analyze_unused_dart2js_test.dart
@@ -18,9 +18,10 @@ const Map<String, List<String>> WHITE_LIST = const {
// Helper methods for debugging should never be called from production code:
"lib/src/helpers/": const [" is never "],
// Node.asLiteralBool is never used.
"lib/src/tree/nodes.dart": const [
- "The method 'asLiteralBool' is never called"],
+ "The method 'asAssert' is never called.",
+ "The method 'asLiteralBool' is never called."],
// Some things in dart_printer are not yet used
"lib/src/dart_backend/backend_ast_nodes.dart": const [" is never "],
« no previous file with comments | « sdk/lib/core/errors.dart ('k') | tests/compiler/dart2js/backend_dart/dart_printer_test.dart » ('j') | no next file with comments »
@@ -18,9 +18,10 @@ const Map<String, List<String>> WHITE_LIST = const {
// Helper methods for debugging should never be called from production code:
"lib/src/helpers/": const [" is never "],
- // Node.asLiteralBool is never used.
+ // Node.asAssert, Node.asLiteralBool is never used.
"lib/src/tree/nodes.dart": const [

Powered by Google App Engine
This is Rietveld 408576698